@@ -1,4 +1,5 @@
-import ezdnac.apic
+from ezdnac.excepts import *
+import ezdnac.dnac
 import requests
 import json
 import re
@@ -13,7 +14,7 @@ authbaseurl = '/api/system/v1/'
 
 #When initialized, populate device parameters:
 #Retreive switchId based on serialnumber
-class device():
+class Device():
 	def __init__(self, dna, **kwargs):
 		self.authToken = dna.authToken
 		self.dnacIP = dna.ip
@@ -21,7 +22,7 @@ class device():
 		self.uid = dna.uid
 		self.pw = dna.pw
 		self.state = ""
-		self.dnac = ezdnac.apic(self.dnacIP, self.uid, pw=self.pw)
+		self.dnac = ezdnac.DnaC(self.dnacIP, self.uid, pw=self.pw)
 		try:
 			self.id = kwargs['id']
 			self.initMethod = 'id'
@@ -162,10 +163,11 @@ class device():
 			  'Content-Type': 'application/json',
 			}
 			response = requests.request("POST", url, headers=headers, json=payload, verify=verifySSL, timeout=10)
+			data = json.loads(response.text)
 			if response.status_code == 202:
 				try:
 					# Trying to get deploymentId from response
-					result = json.loads(response.text)['deploymentId']
+					result = data['deploymentId']
 				except:
 					pass
 				
@@ -179,20 +181,7 @@ class device():
 						self.deploymentId = data
 						return data
 
-				# if no id was found, try to see what the problem is.
-				resultRegex = (re.findall(r'None of the targets are applicable for the template. Hence not deploying', result))
-				if len(resultRegex) is not 0:
-					message = result
-					data['deploymentId'] = None
-					data['message'] = result
-					self.deploymentId = data
-					return data
-				else:
-					data['deploymentId'] = None
-					data['message'] = None
-					self.deploymentId = data
-					return data
-
+			return data
 
 	def deployTemplateStatus(self, **kwargs):
 		try:
@@ -220,7 +209,6 @@ class device():
 			
 			data = json.loads(response.text)
 			
-
 			if 'status' in data:
 				return data['status']
 			else:
@@ -357,6 +345,3 @@ class device():
 		response = requests.request("POST", url, headers=headers, json=payload, verify=verifySSL, timeout=timeout)
 		data = json.loads(response.text)
 		return data
-
-class ezDNACError(Exception):
-    pass
